package composite;

public class Client {

    public static void main(String[] args) {

        // São instanciados os sensores de pressão, temperatura e nível da água
        Sensor pressure = new Sensor();
        Sensor temperature = new Sensor();
        Sensor waterLevel = new Sensor();

        // O monitoramento do exemplo será composto da seguinte condição:
        // (pressure > 60 && waterLevel < 40) || (temperature > 50 || temperature < 10)

        // Para cada operação lógica da condição, um monitoramento simples é criado.
        GreaterThanMonitoring pressureOver60 = new GreaterThanMonitoring(pressure, 60);
        LessThanMonitoring waterLevelBelow40 = new LessThanMonitoring(waterLevel, 40);
        GreaterThanMonitoring temperatureOver50 = new GreaterThanMonitoring(temperature, 50);
        LessThanMonitoring temperatureBelow10 = new LessThanMonitoring(temperature, 10);

        // Um monitoramento composto com uma lista contendo dois monitoramentos
        AndMonitoring pressureAndWaterLevelMonitoring = new AndMonitoring();
        pressureAndWaterLevelMonitoring.addMonitoring(pressureOver60);
        pressureAndWaterLevelMonitoring.addMonitoring(waterLevelBelow40);

        // Um segundo monitoramento composto com uma lista contendo dois monitoramentos
        OrMonitoring temperatureRangeMonitoring = new OrMonitoring();
        temperatureRangeMonitoring.addMonitoring(temperatureOver50);
        temperatureRangeMonitoring.addMonitoring(temperatureBelow10);

        // O monitoramento principal contem os dois monitoramentos compostos anteriores
        OrMonitoring mainMonitoring = new OrMonitoring();
        mainMonitoring.addMonitoring(pressureAndWaterLevelMonitoring);
        mainMonitoring.addMonitoring(temperatureRangeMonitoring);

        // Sensores identificam valores
        pressure.setValue(50);
        waterLevel.setValue(45);
        temperature.setValue(55);

        if(mainMonitoring.evaluateCondition()) {
            System.out.println("Uma falha foi detectada!");
        } else {
            System.out.println("Nenhuma falha foi detectada.");
        }

    }

}
